--- loncom/xml/lonplot.pm	2004/01/07 18:16:02	1.94
+++ loncom/xml/lonplot.pm	2004/03/08 17:31:37	1.95
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Dynamic plot
 #
-# $Id: lonplot.pm,v 1.94 2004/01/07 18:16:02 matthew Exp $
+# $Id: lonplot.pm,v 1.95 2004/03/08 17:31:37 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -401,7 +401,7 @@ required.  Unfortunately, you must make
 in the order gnuplot expects the data.
 </p><p>
 Specifying the data should usually be done with a perl variable or array, 
-such as \@Xdata and \@Ydata.  You may also specify numerical data seperated 
+such as \@Xdata and \@Ydata.  You may also specify numerical data separated 
 by commas.  Again, the order of the <b>data</b> tags is important.  The
 first tag will be the X data and the second will be the Y data.
 </p>
@@ -512,7 +512,7 @@ sub end_gnuplot {
     my $randnumber;
     # need to call rand everytime start_script would evaluate, as the
     # safe space rand number generator and the global rand generator 
-    # are not seperate
+    # are not separate
     if ($target eq 'web' || $target eq 'tex' || $target eq 'grade' ||
 	$target eq 'answer') {
       $randnumber=int(rand(1000));
@@ -887,7 +887,7 @@ sub start_data {
 	my @data;
 	if ($datatext =~ /,/) { # comma deliminated
 	    @data = split /,/,$datatext;
-	} else { # Assume it's space seperated.
+	} else { # Assume it's space separated.
 	    @data = split / /,$datatext;
 	}
 	for (my $i=0;$i<=$#data;$i++) {